==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/Other/ServiceInternetAnalyzerProfiles.md <==
# ServiceInternetAnalyzerProfiles


```text
azure-4/Item/Other/ServiceInternetAnalyzerProfiles
```

```text
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')
```



| Illustration | ServiceInternetAnalyzerProfiles | ServiceInternetAnalyzerProfilesCard | ServiceInternetAnalyzerProfilesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfiles.png) | ![illustration for ServiceInternetAnalyzerProfiles](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfiles.Local.png) | ![illustration for ServiceInternetAnalyzerProfilesCard](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfilesCard.Local.png) | ![illustration for ServiceInternetAnalyzerProfilesGroup](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfilesGroup.Local.png) |




## ServiceInternetAnalyzerProfiles

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfiles
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfiles('ServiceInternetAnalyzerProfiles', 'Service Internet Analyzer Profiles', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfiles
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfiles('ServiceInternetAnalyzerProfiles', 'Service Internet Analyzer Profiles', 'an optional tech label')
@enduml
```

## ServiceInternetAnalyzerProfilesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesCard
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesCard('ServiceInternetAnalyzerProfilesCard', 'Service Internet Analyzer Profiles Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesCard
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesCard('ServiceInternetAnalyzerProfilesCard', 'Service Internet Analyzer Profiles Card', 'an optional description')
@enduml
```

## ServiceInternetAnalyzerProfilesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesGroup
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesGroup('ServiceInternetAnalyzerProfilesGroup', 'Service Internet Analyzer Profiles Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesGroup
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesGroup('ServiceInternetAnalyzerProfilesGroup', 'Service Internet Analyzer Profiles Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/Other/ServiceInternetAnalyzerProfiles.md <==
# ServiceInternetAnalyzerProfiles


```text
azure-4/Item/Other/ServiceInternetAnalyzerProfiles
```

```text
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')
```



| Illustration | ServiceInternetAnalyzerProfiles | ServiceInternetAnalyzerProfilesCard | ServiceInternetAnalyzerProfilesGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfiles.png) | ![illustration for ServiceInternetAnalyzerProfiles](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfiles.Local.png) | ![illustration for ServiceInternetAnalyzerProfilesCard](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfilesCard.Local.png) | ![illustration for ServiceInternetAnalyzerProfilesGroup](../../../azure-4/Item/Other/ServiceInternetAnalyzerProfilesGroup.Local.png) |




## ServiceInternetAnalyzerProfiles

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfiles
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfiles('ServiceInternetAnalyzerProfiles', 'Service Internet Analyzer Profiles', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfiles
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfiles('ServiceInternetAnalyzerProfiles', 'Service Internet Analyzer Profiles', 'an optional tech label')
@enduml
```

## ServiceInternetAnalyzerProfilesCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesCard
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesCard('ServiceInternetAnalyzerProfilesCard', 'Service Internet Analyzer Profiles Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesCard
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesCard('ServiceInternetAnalyzerProfilesCard', 'Service Internet Analyzer Profiles Card', 'an optional description')
@enduml
```

## ServiceInternetAnalyzerProfilesGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesGroup
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesGroup('ServiceInternetAnalyzerProfilesGroup', 'Service Internet Analyzer Profiles Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceInternetAnalyzerProfilesGroup
include('azure-4/Item/Other/ServiceInternetAnalyzerProfiles')

' renders the element
ServiceInternetAnalyzerProfilesGroup('ServiceInternetAnalyzerProfilesGroup', 'Service Internet Analyzer Profiles Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
